@@ -523,9 +523,28 @@ void user_to_window(XPoint upt, XPoint *wpt)
   wpt->y = (short)tmpy;
 }
 
-/*------------------------------------------------------------------------*/
-/* Transformations in the object hierarchy				  */
-/*------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Transformations in the object hierarchy				*/
+/*----------------------------------------------------------------------*/
+
+/*----------------------------------------------------------------------*/
+/* Return rotation relative to the top level				*/
+/*----------------------------------------------------------------------*/
+
+int UTopRotate()
+{
+   int rotate;
+   Matrix *ctm = DCTM;
+   float topscale = UTopScale();
+   float rads = (float)atan2((double)(ctm->d / topscale),
+			(double)(ctm->a / topscale));
+
+   return (int)(rads / RADFAC);
+}
+
+/*----------------------------------------------------------------------*/
+/* Return scale relative to top-level					*/
+/*----------------------------------------------------------------------*/
 
 float UTopScale()
 {
@@ -533,7 +552,7 @@ float UTopScale()
    return (float)(sqrt((double)(ctm->a * ctm->a + ctm->d * ctm->d)));
 }
 
-/*------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
 
 float UTopTransScale(float length)
 {
@@ -1587,7 +1606,6 @@ void zoomview(xcWidget w, caddr_t clientdata, caddr_t calldata)
 	eventmode == CATMOVE_MODE) {
 
       centerview(areawin->topinstance);
-      invalidate_graphics(topobject);
       areawin->lastbackground = NULL;
       renderbackground();
       refresh(NULL, NULL, NULL);
