@@ -98,23 +98,6 @@ short *collect_graphics(short *pagelist)
    return glist;
 }
 
-/*----------------------------------------------------------------------*/
-/* Declare all graphic image targets to be invalid.   This is required	*/
-/* on any change in the zoom factor of the current object.		*/
-/*----------------------------------------------------------------------*/
-
-void invalidate_graphics(objectptr thisobj)
-{
-   genericptr *gp;
-
-   for (gp = thisobj->plist; gp < thisobj->plist + thisobj->parts; gp++) {
-      if (IS_GRAPHIC(*gp))
-	 TOGRAPHIC(gp)->valid = FALSE;
-      else if (IS_OBJINST(*gp))
-	 invalidate_graphics((TOOBJINST(gp))->thisobject);
-   }
-}
-
 /*----------------------------------------------------------------------*/
 /* Generate the target view of the indicated graphic image, combining	*/
 /* the image's scale and rotation and the zoom factor of the current	*/
@@ -123,7 +106,7 @@ void invalidate_graphics(objectptr thisobj)
 
 void transform_graphic(graphicptr gp)
 {
-    int width, height, twidth, theight;
+    int width, height, twidth, theight, rotation;
     float scale;
     double cosr, sinr;
     int x, y, c, s, hw, hh, thw, thh, xorig, yorig, crot;
@@ -131,19 +114,24 @@ void transform_graphic(graphicptr gp)
     static GC cmgc = (GC)NULL;
 
     scale = gp->scale * UTopTransScale(1.0);
+    rotation = gp->rotation + UTopRotate();
 
-    if (gp->rotation == 360) gp->rotation = 0;
-    else if (gp->rotation < 0) gp->rotation += 360;
+    if (rotation >= 360) rotation -= 360;
+    else if (rotation < 0) rotation += 360;
 
-    cosr = cos(RADFAC * gp->rotation);
-    sinr = sin(RADFAC * gp->rotation);
+    /* Check if the top-level rotation and scale match the	*/
+    /* saved target image.  If so, then we're done.		*/
+    if ((rotation == gp->trot) && (scale == gp->tscale)) return;
+
+    cosr = cos(RADFAC * rotation);
+    sinr = sin(RADFAC * rotation);
     c = (int)(8192 * cosr / scale);
     s = (int)(8192 * sinr / scale);
 
     /* Determine the necessary width and height of the pixmap	*/
     /* that fits the rotated and scaled image.			*/
 
-    crot = gp->rotation;
+    crot = rotation;
     if (crot > 90 && crot < 180) crot = 180 - crot;
     if (crot > 270 && crot < 360) crot = 360 - crot;
     cosr = cos(RADFAC * crot);
@@ -168,11 +156,10 @@ void transform_graphic(graphicptr gp)
        XDestroyImage(gp->target);
        gp->target = (XImage *)NULL;
        gp->clipmask = (Pixmap)NULL;
-       gp->valid = FALSE;
        return;
     }
 
-    if (gp->rotation != 0) {
+    if (rotation != 0) {
        gp->clipmask = XCreatePixmap(dpy, areawin->window, twidth, theight, 1);
        if (cmgc == (GC)NULL) {
           XGCValues values;
@@ -204,7 +191,8 @@ void transform_graphic(graphicptr gp)
 	       XDrawPoint(dpy, gp->clipmask, cmgc, x + thw, y + thh);
 	}
     }
-    gp->valid = TRUE;
+    gp->tscale = scale;
+    gp->trot = rotation;
 }
 
 /*----------------------------------------------------------------------*/
@@ -215,12 +203,14 @@ void transform_graphic(graphicptr gp)
 void UDrawGraphic(graphicptr gp)
 {
     XPoint ppt;
-    /* int width, height; (jdk) */
 
-    if (gp->valid == FALSE) transform_graphic(gp);
-    if (gp->valid == FALSE) return;			/* Error condition */
+    /* transform to current scale and rotation, if necessary */
+    transform_graphic(gp);
 
-    user_to_window(gp->position, &ppt);
+    /* transform to current position */
+    UTransformbyCTM(DCTM, &(gp->position), &ppt, 1);
+
+    /* user_to_window(gp->position, &ppt); */
 
     ppt.x -= (gp->target->width >> 1);
     ppt.y -= (gp->target->height >> 1);
@@ -385,7 +375,6 @@ graphicptr new_graphic(objinstptr destinst, char *filename, int px, int py)
     NEW_GRAPHIC(gp, destobject);
     destobject->parts++;
 
-    (*gp)->valid = FALSE;
     (*gp)->scale = 1.0;
     (*gp)->position.x = px;
     (*gp)->position.y = py;
@@ -395,6 +384,8 @@ graphicptr new_graphic(objinstptr destinst, char *filename, int px, int py)
     (*gp)->clipmask = (Pixmap)NULL;
     (*gp)->source = iptr->image;
     (*gp)->target = NULL;
+    (*gp)->trot = 0;
+    (*gp)->tscale = 0;
 
     calcbboxvalues(locdestinst, (genericptr *)gp);
     updatepagebounds(destobject);
