@@ -1319,13 +1319,14 @@ Boolean makestringparam(objectptr refobject, char *key, stringpart *strptr)
 /* the new parameter will be linked to the existing one.	*/
 /*--------------------------------------------------------------*/
 
-void makenumericalp(genericptr *gelem, u_int mode, char *key)
+void makenumericalp(genericptr *gelem, u_int mode, char *key, short cycle)
 {
    oparamptr ops, newops;
    eparamptr epp;
    XPoint *pptr;
    char new_key[7], *keyptr;
    int pidx;
+   short loccycle = cycle;
 
    /* Numerical parameters have designated keys to avoid the necessity	*/
    /* of having to specify a key, to avoid conflicts with PostScript	*/
@@ -1489,16 +1490,17 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
 	    }
 	    break;
          case POLYGON:
+	    if (loccycle == -1) loccycle = TOPOLY(gelem)->cycle;
 	    switch(mode) {
 	       case P_POSITION_X:
-	          pptr = TOPOLY(gelem)->points + areawin->editcycle; 
+	          pptr = TOPOLY(gelem)->points + loccycle;
 	          newops->parameter.ivalue = (int)pptr->x;
-	          epp->pdata.pointno = areawin->editcycle;
+	          epp->pdata.pointno = TOPOLY(gelem)->cycle;
 	          break;
 	       case P_POSITION_Y:
-	          pptr = TOPOLY(gelem)->points + areawin->editcycle; 
+	          pptr = TOPOLY(gelem)->points + loccycle;
 	          newops->parameter.ivalue = (int)pptr->y;
-	          epp->pdata.pointno = areawin->editcycle;
+	          epp->pdata.pointno = TOPOLY(gelem)->cycle;
 	          break;
 	       case P_STYLE:
 	          newops->parameter.ivalue = (int)TOPOLY(gelem)->style;
@@ -1510,16 +1512,17 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
 	    }
 	    break;
          case SPLINE:
+	    if (loccycle == -1) loccycle = TOSPLINE(gelem)->cycle;
 	    switch(mode) {
 	       case P_POSITION_X:
-	          pptr = TOSPLINE(gelem)->ctrl + areawin->editcycle; 
+	          pptr = TOSPLINE(gelem)->ctrl + loccycle;
 	          newops->parameter.ivalue = (int)pptr->x;
-	          epp->pdata.pointno = areawin->editcycle;
+	          epp->pdata.pointno = TOSPLINE(gelem)->cycle;
 	          break;
 	       case P_POSITION_Y:
-	          pptr = TOSPLINE(gelem)->ctrl + areawin->editcycle; 
+	          pptr = TOSPLINE(gelem)->ctrl + loccycle;
 	          newops->parameter.ivalue = (int)pptr->y;
-	          epp->pdata.pointno = areawin->editcycle;
+	          epp->pdata.pointno = TOSPLINE(gelem)->cycle;
 	          break;
 	       case P_STYLE:
 	          newops->parameter.ivalue = (int)TOSPLINE(gelem)->style;
@@ -2021,7 +2024,7 @@ void unparameterize(int mode)
 /* Wrapper for makeparam()					*/
 /*--------------------------------------------------------------*/
 
-void parameterize(int mode, char *key)
+void parameterize(int mode, char *key, short cycle)
 {
    short *fselect, ptype;
    labelptr settext;
@@ -2042,11 +2045,11 @@ void parameterize(int mode, char *key)
          makeparam(settext, key);
       }
       else if (mode == P_POSITION) {
-	 makenumericalp(topobject->plist + (*fselect), P_POSITION_X, key);
-	 makenumericalp(topobject->plist + (*fselect), P_POSITION_Y, key);
+	 makenumericalp(topobject->plist + (*fselect), P_POSITION_X, key, cycle);
+	 makenumericalp(topobject->plist + (*fselect), P_POSITION_Y, key, cycle);
       }
       else
-	 makenumericalp(topobject->plist + (*fselect), mode, key);
+	 makenumericalp(topobject->plist + (*fselect), mode, key, cycle);
    }
    unselect_all();
    setparammarks(NULL);
