@@ -99,6 +99,7 @@ extern void unjoin(void);
 extern labelptr findlabelcopy(labelptr, stringpart *);
 extern Boolean neartest(XPoint *, XPoint *);
 extern void join(void);
+extern genericptr getsubpart(pathptr);
 
 /* interactive manipulation of elements */
 extern void splinebutton(int, int);
@@ -108,8 +109,9 @@ extern void trackarc(xcWidget, caddr_t, caddr_t);
 extern void boxbutton(int, int);
 extern void trackbox(xcWidget, caddr_t, caddr_t);
 extern void trackwire(xcWidget, caddr_t, caddr_t);
-extern void startwire(XPoint);
+extern void startwire(XPoint *);
 extern void trackpoly(xcWidget, caddr_t, caddr_t);
+extern void trackpath(xcWidget, caddr_t, caddr_t);
 extern void setendpoint(short *, short, XPoint **, XPoint *);
 extern void wire_op(int, int ,int);
 
@@ -143,8 +145,10 @@ extern void zoominrefresh(int, int);
 extern void zoomoutrefresh(int, int);
 extern void panrefresh(u_int, int, int, float);
 extern void checkwarp(XPoint *);
-extern int checkcycle(short, short);
+extern void warparccycle(arcptr);
+extern int checkcycle(genericptr, short);
 extern void copyvirtual(void);
+extern void nextpathcycle(pathptr, short);
 extern void nextpolycycle(polyptr, short);
 extern void nextsplinecycle(splineptr, short);
 extern void nextarccycle(arcptr, short);
@@ -169,7 +173,7 @@ extern void xlib_drag(xcWidget, caddr_t, XEvent *);
 extern void elemrotate(genericptr *, short, XPoint *);
 extern void elementrotate(short, XPoint *);
 extern void edit(int, int);
-extern void pathedit(genericptr *, short);
+extern void pathedit(genericptr);
 extern void xc_lower(short *);
 extern void xc_raise(short *);
 extern void exchange(void);
@@ -201,11 +205,13 @@ extern void selectsave(xcWidget, caddr_t, caddr_t);
 extern void arceditpush(arcptr);
 extern void splineeditpush(splineptr);
 extern void polyeditpush(polyptr);
+extern void patheditpush(pathptr);
 extern pointlist copypoints(pointlist, int);
 extern void labelcopy(labelptr, labelptr);
 extern void arccopy(arcptr, arcptr);
 extern void polycopy(polyptr, polyptr);
 extern void splinecopy(splineptr, splineptr);
+extern void pathcopy(pathptr, pathptr);
 extern void instcopy(objinstptr, objinstptr);
 extern void delete_tagged(objectptr);
 extern void createcopies(void);
@@ -214,7 +220,7 @@ extern void copy_op(int, int, int);
 extern Boolean checkmultiple(XButtonEvent *);
 extern void continue_op(int, int, int);
 extern void finish_op(int, int, int);
-extern void path_op(genericptr *, int, int, int);
+extern void path_op(genericptr, int, int, int);
 extern void resizearea(xcWidget, caddr_t, caddr_t);
 extern void drawarea(xcWidget, caddr_t, caddr_t);
 extern void standard_element_delete(short);
@@ -341,6 +347,7 @@ extern float fsqwirelen(XfPoint *, XfPoint *);
 extern int wirelength(XPoint *, XPoint *);
 extern long finddist(XPoint *,XPoint *, XPoint *);
 extern void calcarc(arcptr);
+extern void decomposearc(pathptr);
 extern void initsplines(void);
 extern void computecoeffs(splineptr, float *, float *, float *, float *,
                           float *, float *);
@@ -378,7 +385,7 @@ extern void UTransformPoints(XPoint *, XPoint *, short, XPoint, float,
                              short);
 extern void InvTransformPoints(XPoint *, XPoint *, short, XPoint, float,
                              short);
-extern void manhattanize(XPoint *, polyptr);
+extern void manhattanize(XPoint *, polyptr, short, Boolean);
 extern void bboxcalc(short, short *, short *);
 extern void calcextents(genericptr *, short *, short *, short *, short *);
 extern void objinstbbox(objinstptr, XPoint *, Boolean);
@@ -721,7 +728,7 @@ extern Boolean makestringparam(objectptr, char *, stringpart *);
 extern void std_eparam(genericptr, char *);
 extern void indicateparams(genericptr);
 extern void setparammarks(genericptr);
-extern void makenumericalp(genericptr *, u_int, char *);
+extern void makenumericalp(genericptr *, u_int, char *, short);
 extern void noparmstrcpy(u_char *, u_char *);
 extern void insertparam(void);
 extern void makeparam(labelptr, char *);
@@ -730,7 +737,7 @@ extern stringpart *searchparam(stringpart *);
 extern void unmakeparam(labelptr, stringpart *);
 extern void removenumericalp(genericptr *, u_int);         
 extern void unparameterize(int);
-extern void parameterize(int, char *);
+extern void parameterize(int, char *, short);
 extern genericptr findparam(objectptr, void *, u_char);
 extern Boolean paramcross(objectptr, labelptr);
 extern oparamptr parampos(objectptr, labelptr, char *, short *, short *);
@@ -864,6 +871,8 @@ extern void draw_all_selected(void);
 extern void clearselects_noundo(void);
 extern void clearselects(void);
 extern void unselect_all(void);
+extern void select_connected_pins();
+extern void reset_connected_pins();
 extern selection *recurselect(short, u_char, pushlistptr *);
 extern short *recurse_select_element(short, u_char);
 extern void startselect(void);
