@@ -85,10 +85,10 @@ Boolean hasparameter(labelptr curlabel)
 
 void joinlabels()
 {
-   genericptr *genobj;
+  /* genericptr *genobj; (jdk) */
    short *jl;
    stringpart *endpart;
-   int tpos;
+   /* int tpos; (jdk) */
    labelptr dest, source;
 
    if (areawin->selects < 2) {
@@ -525,7 +525,7 @@ static char *nonprint[] = {
 	"Tab_Stop", "Tab_Forward", "Tab_Backward",
 	"Halfspace", "Quarterspace", "<Return>",
 	"Font", "Scale", "Color", "Kern", 
-        "Parameter", ">", "Net_Name", "Error"};
+        "Parameter", ">", "Net_Name", "Error", NULL}; /* (jdk) */
 
 /*----------------------------------------------------------------------*/
 /* charprint():  							*/
@@ -852,7 +852,7 @@ Boolean pin_is_bus(labelptr thislab, objinstptr thisinst)
 {
    stringpart *strptr;
    char *busptr;
-   int busidx;
+   /* int busidx; (jdk) */
    Boolean found_delimiter = FALSE;
 
    for (strptr = thislab->string; strptr != NULL; strptr =
@@ -1606,7 +1606,7 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
        }
    }
 
-enddraw:
+   /* enddraw: (jdk) */
 
    if (tabstops != NULL) free(tabstops);
 
@@ -1855,7 +1855,7 @@ void redrawtext(labelptr curlabel)
 
 void composefontlib(short cfont)
 {
-   genericptr *pgen;
+  /* genericptr *pgen; (jdk) */
    objinstptr *drawinst;
    objectptr *curlib, libobj, nullobj;
    objectptr directory = xobjs.libtop[FONTLIB]->thisobject;
