@@ -107,7 +107,7 @@ ERROR: Cannot compile without knowing the size of a pointer.  See xcircuit.h.
 #define ARC		0x08
 #define SPLINE  	0x10
 #define PATH		0x20
-#define GRAPHIC		0x40	/* reserved; unused, for now.		*/
+#define GRAPHIC		0x40
 #define ARRAY		0x80	/* reserved; unused, for now.		*/
 
 #define REMOVE_TAG	0x100	/* element to be removed from netlist	*/
@@ -713,6 +713,8 @@ typedef struct {
    float	  scale;
    XImage	  *source;	/* source data */
    XImage	  *target;	/* target (scaled) data */
+   short	  trot;		/* target rotation */
+   float	  tscale;	/* target scale (0 = uninitialized) */
    Pixmap	  clipmask;	/* clipmask for non-manhattan rotations */
    Boolean	  valid;	/* does target need to be regenerated? */
 } graphic, *graphicptr;
